# eric7.EricWidgets.EricMainWindow

Module implementing a main window class with styling support.

### Global Attributes

None

### Classes

EricMainWindow | Class implementing a main window with styling support.

### Functions

None

## EricMainWindow

Class implementing a main window with styling support.

### Derived from

QMainWindow

### Class Attributes

None

### Class Methods

None

### Methods

EricMainWindow | Constructor
setStyle | Public method to set the style of the interface.

### Static Methods

None

#### EricMainWindow (Constructor)

EricMainWindow(parent=None)

Constructor

parent (QWidget)
  reference to the parent widget

#### EricMainWindow.setStyle

setStyle(styleName, styleSheetFile, itemClickBehavior="default")

Public method to set the style of the interface.

styleName (str)
  name of the style to set
styleSheetFile (str)
  name of a style sheet file to read to overwrite defaults of the given style
itemClickBehavior (str (optional))
  string describing the item activation behavior (one of "default", "doubleclick" or "singleclick") (defaults to "default")

Up